# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.reports_public_report_response import ReportsPublicReportResponse

class TestReportsPublicReportResponse(unittest.TestCase):
    """ReportsPublicReportResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ReportsPublicReportResponse:
        """Test ReportsPublicReportResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ReportsPublicReportResponse`
        """
        model = ReportsPublicReportResponse()
        if include_optional:
            return ReportsPublicReportResponse(
                branding = neurograph.v1.models.reports/public_branding.reports.PublicBranding(
                    background_url = '', 
                    logo_url = '', 
                    primary_color = '', 
                    secondary_color = '', 
                    tertiary_color = '', ),
                call_to_action = '',
                client_name = '',
                embed_url = '',
                error = '',
                executive_summary = '',
                id = '',
                key_highlights = [
                    ''
                    ],
                key_stats = [
                    56
                    ],
                linked_concepts = [
                    ''
                    ],
                linked_themes = [
                    ''
                    ],
                main_insights = [
                    ''
                    ],
                name = '',
                og_image_url = '',
                report_type = '',
                report_type_label = '',
                thumbnail_url = '',
                ts_created = ''
            )
        else:
            return ReportsPublicReportResponse(
        )
        """

    def testReportsPublicReportResponse(self):
        """Test ReportsPublicReportResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
