# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.client_system_healthcheck_detail_response import ClientSystemHealthcheckDetailResponse

class TestClientSystemHealthcheckDetailResponse(unittest.TestCase):
    """ClientSystemHealthcheckDetailResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ClientSystemHealthcheckDetailResponse:
        """Test ClientSystemHealthcheckDetailResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ClientSystemHealthcheckDetailResponse`
        """
        model = ClientSystemHealthcheckDetailResponse()
        if include_optional:
            return ClientSystemHealthcheckDetailResponse(
                data = neurograph.v1.models.client/system_healthcheck_snapshot.client.SystemHealthcheckSnapshot(
                    client_id = '', 
                    error_json = [
                        56
                        ], 
                    error_message = '', 
                    id = '', 
                    queries = [
                        neurograph.v1.models.client/system_healthcheck_query_result.client.SystemHealthcheckQueryResult(
                            check_key = '', 
                            display_name = '', 
                            error_message = '', 
                            query_id = '', 
                            query_version = 56, 
                            result_json = [
                                56
                                ], 
                            result_success = True, 
                            row_count = 56, 
                            status = '', 
                            ts_finished = '', 
                            ts_started = '', )
                        ], 
                    result_success = True, 
                    run_date = '', 
                    status = '', 
                    summary_json = [
                        56
                        ], 
                    ts_finished = '', 
                    ts_started = '', ),
                error = ''
            )
        else:
            return ClientSystemHealthcheckDetailResponse(
        )
        """

    def testClientSystemHealthcheckDetailResponse(self):
        """Test ClientSystemHealthcheckDetailResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
