# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.knowledge_product_response import KnowledgeProductResponse

class TestKnowledgeProductResponse(unittest.TestCase):
    """KnowledgeProductResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> KnowledgeProductResponse:
        """Test KnowledgeProductResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `KnowledgeProductResponse`
        """
        model = KnowledgeProductResponse()
        if include_optional:
            return KnowledgeProductResponse(
                data = [
                    neurograph.v1.models.db/knowledge_product.db.KnowledgeProduct(
                        client_id = '', 
                        entity_id = '', 
                        handle = '', 
                        overview = '', 
                        product_hash = '', 
                        product_id = neurograph.v1.models.pgtype/int8.pgtype.Int8(
                            int64 = 56, 
                            valid = True, ), 
                        summary = '', 
                        title = '', 
                        type = '', )
                    ],
                error = '',
                query = neurograph.v1.models.knowledge/product_query.knowledge.ProductQuery(
                    client_id = '', 
                    handle = '', 
                    limit = 56, 
                    offset = 56, 
                    product_hash = '', 
                    product_id = 56, 
                    title = '', 
                    type = '', )
            )
        else:
            return KnowledgeProductResponse(
        )
        """

    def testKnowledgeProductResponse(self):
        """Test KnowledgeProductResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
