# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.reporting_customer_insights_response import ReportingCustomerInsightsResponse

class TestReportingCustomerInsightsResponse(unittest.TestCase):
    """ReportingCustomerInsightsResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ReportingCustomerInsightsResponse:
        """Test ReportingCustomerInsightsResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ReportingCustomerInsightsResponse`
        """
        model = ReportingCustomerInsightsResponse()
        if include_optional:
            return ReportingCustomerInsightsResponse(
                age_breakdown = [
                    neurograph.v1.models.reporting/age_breakdown_row.reporting.AgeBreakdownRow(
                        age_group = '', 
                        avg_aov = 1.337, 
                        avg_ltv = 1.337, 
                        conversion_rate = 1.337, 
                        customer_count = 56, 
                        total_orders = 56, )
                    ],
                cached = True,
                error = '',
                summary = neurograph.v1.models.reporting/summary_kpis.reporting.SummaryKPIs(
                    avg_ltv = 1.337, 
                    conversion_rate = 1.337, 
                    conversion_window_days = 56, 
                    predicted_pipeline_value = 1.337, 
                    total_visitors = 56, ),
                traffic_trend = [
                    neurograph.v1.models.reporting/traffic_trend_day.reporting.TrafficTrendDay(
                        date = '', 
                        new_customers = 56, 
                        returning_customers = 56, )
                    ],
                traffic_value_pipeline = [
                    neurograph.v1.models.reporting/traffic_pipeline_day.reporting.TrafficPipelineDay(
                        daily_total = neurograph.v1.models.reporting/daily_total.reporting.DailyTotal(
                            avg_value_per_visitor = 1.337, 
                            predicted_value = 1.337, 
                            visitors = 56, ), 
                        date = '', 
                        intent_bands = {
                            'key' : neurograph.v1.models.reporting/intent_band_data.reporting.IntentBandData(
                                avg_conversion_prob = 1.337, 
                                predicted_value = 1.337, 
                                visitor_count = 56, )
                            }, )
                    ]
            )
        else:
            return ReportingCustomerInsightsResponse(
        )
        """

    def testReportingCustomerInsightsResponse(self):
        """Test ReportingCustomerInsightsResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
