# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.organizations_theme_preset_update_request import OrganizationsThemePresetUpdateRequest

class TestOrganizationsThemePresetUpdateRequest(unittest.TestCase):
    """OrganizationsThemePresetUpdateRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> OrganizationsThemePresetUpdateRequest:
        """Test OrganizationsThemePresetUpdateRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `OrganizationsThemePresetUpdateRequest`
        """
        model = OrganizationsThemePresetUpdateRequest()
        if include_optional:
            return OrganizationsThemePresetUpdateRequest(
                category = 'custom',
                color1 = '#FF6B35',
                color2 = '#F7931E',
                color3 = '#FFC857',
                color4 = '#2D5016',
                color5 = '#5C8A3D',
                description = 'An updated theme',
                id = 1,
                is_active = True,
                name = 'Updated Theme',
                preview_url = 'https://example.com/preview.png',
                primary_color = '#0066CC',
                secondary_color = '#00A3E0',
                tags = [custom, colorful],
                tertiary_color = '#7FDBFF'
            )
        else:
            return OrganizationsThemePresetUpdateRequest(
        )
        """

    def testOrganizationsThemePresetUpdateRequest(self):
        """Test OrganizationsThemePresetUpdateRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
