# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.reporting_portfolio_activity_response import ReportingPortfolioActivityResponse

class TestReportingPortfolioActivityResponse(unittest.TestCase):
    """ReportingPortfolioActivityResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ReportingPortfolioActivityResponse:
        """Test ReportingPortfolioActivityResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ReportingPortfolioActivityResponse`
        """
        model = ReportingPortfolioActivityResponse()
        if include_optional:
            return ReportingPortfolioActivityResponse(
                by_client = [
                    neurograph.v1.models.reporting/client_breakdown.reporting.ClientBreakdown(
                        client_uid = '', 
                        org_uid = '', 
                        purchases = 56, 
                        sessions = 56, )
                    ],
                by_org = [
                    neurograph.v1.models.reporting/org_breakdown.reporting.OrgBreakdown(
                        org_uid = '', 
                        purchases = 56, 
                        sessions = 56, )
                    ],
                cached = True,
                date_range = neurograph.v1.models.reporting/date_range.reporting.DateRange(
                    end_date = '', 
                    start_date = '', ),
                error = '',
                portfolio = neurograph.v1.models.reporting/portfolio_metrics.reporting.PortfolioMetrics(
                    daily_purchases = [
                        neurograph.v1.models.reporting/daily_summary.reporting.DailySummary(
                            count = 56, 
                            date = '', )
                        ], 
                    daily_sessions = [
                        neurograph.v1.models.reporting/daily_summary.reporting.DailySummary(
                            count = 56, 
                            date = '', )
                        ], 
                    total_purchases = 56, 
                    total_sessions = 56, ),
                query_time_ms = 56
            )
        else:
            return ReportingPortfolioActivityResponse(
        )
        """

    def testReportingPortfolioActivityResponse(self):
        """Test ReportingPortfolioActivityResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
