# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.reporting_traffic_pipeline_day import ReportingTrafficPipelineDay

class TestReportingTrafficPipelineDay(unittest.TestCase):
    """ReportingTrafficPipelineDay unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ReportingTrafficPipelineDay:
        """Test ReportingTrafficPipelineDay
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ReportingTrafficPipelineDay`
        """
        model = ReportingTrafficPipelineDay()
        if include_optional:
            return ReportingTrafficPipelineDay(
                daily_total = neurograph.v1.models.reporting/daily_total.reporting.DailyTotal(
                    avg_value_per_visitor = 1.337, 
                    predicted_value = 1.337, 
                    visitors = 56, ),
                var_date = '',
                intent_bands = {
                    'key' : neurograph.v1.models.reporting/intent_band_data.reporting.IntentBandData(
                        avg_conversion_prob = 1.337, 
                        predicted_value = 1.337, 
                        visitor_count = 56, )
                    }
            )
        else:
            return ReportingTrafficPipelineDay(
        )
        """

    def testReportingTrafficPipelineDay(self):
        """Test ReportingTrafficPipelineDay"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
