# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.organizations_gamma_theme_settings import OrganizationsGammaThemeSettings

class TestOrganizationsGammaThemeSettings(unittest.TestCase):
    """OrganizationsGammaThemeSettings unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> OrganizationsGammaThemeSettings:
        """Test OrganizationsGammaThemeSettings
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `OrganizationsGammaThemeSettings`
        """
        model = OrganizationsGammaThemeSettings()
        if include_optional:
            return OrganizationsGammaThemeSettings(
                colors = neurograph.v1.models.organizations/gamma_color_settings.organizations.GammaColorSettings(
                    adjust_for_accessibility = True, 
                    body_color = '', 
                    card_background_color = '', 
                    heading_color = '', 
                    page_background = '', 
                    page_background_color = '', 
                    primary_accent_color = '', 
                    secondary_accent_colors = [
                        ''
                        ], ),
                design = neurograph.v1.models.organizations/gamma_design_settings.organizations.GammaDesignSettings(
                    blocks = neurograph.v1.models.blocks.blocks(), 
                    buttons = neurograph.v1.models.buttons.buttons(), 
                    cards = neurograph.v1.models.cards.cards(), ),
                fonts = neurograph.v1.models.organizations/gamma_font_settings.organizations.GammaFontSettings(
                    body_base_size = 56, 
                    body_color = '', 
                    body_font = '', 
                    body_letter_spacing = 1.337, 
                    body_line_height = 1.337, 
                    body_weight = '', 
                    heading_color = '', 
                    heading_font = '', 
                    heading_letter_spacing = 1.337, 
                    heading_line_height = 1.337, 
                    heading_weight = '', ),
                reasoning = ''
            )
        else:
            return OrganizationsGammaThemeSettings(
        )
        """

    def testOrganizationsGammaThemeSettings(self):
        """Test OrganizationsGammaThemeSettings"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
