# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.client_urls_response import ClientUrlsResponse

class TestClientUrlsResponse(unittest.TestCase):
    """ClientUrlsResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ClientUrlsResponse:
        """Test ClientUrlsResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ClientUrlsResponse`
        """
        model = ClientUrlsResponse()
        if include_optional:
            return ClientUrlsResponse(
                data = [
                    neurograph.v1.models.client/url_row.client.UrlRow(
                        client_id = 'cli_12345', 
                        customer_environment = '', 
                        id = 56, 
                        is_active = True, 
                        probes = [
                            neurograph.v1.models.client/probe.client.Probe(
                                error = '', 
                                final_url = '', 
                                has_snapshot = True, 
                                id = '', 
                                is_ok = True, 
                                method = '', 
                                requested_url = '', 
                                response_ms = 56, 
                                status_code = 56, 
                                ts_checked = 56, )
                            ], 
                        ts_created = 56, 
                        url = 'example.com', )
                    ],
                error = '',
                query_client_id = '',
                total_rows = 56
            )
        else:
            return ClientUrlsResponse(
        )
        """

    def testClientUrlsResponse(self):
        """Test ClientUrlsResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
