# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.organizations_brand_detail_response import OrganizationsBrandDetailResponse

class TestOrganizationsBrandDetailResponse(unittest.TestCase):
    """OrganizationsBrandDetailResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> OrganizationsBrandDetailResponse:
        """Test OrganizationsBrandDetailResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `OrganizationsBrandDetailResponse`
        """
        model = OrganizationsBrandDetailResponse()
        if include_optional:
            return OrganizationsBrandDetailResponse(
                accessibility_level = '',
                background_img_url = '',
                color1 = '',
                color2 = '',
                color3 = '',
                color4 = '',
                color5 = '',
                components = neurograph.v1.models.organizations/component_config.organizations.ComponentConfig(
                    border_radius = '', 
                    button_style = '', 
                    card_style = '', ),
                dark_mode_enabled = True,
                error = '',
                generation_metadata = neurograph.v1.models.organizations/generation_metadata.organizations.GenerationMetadata(
                    generated_at = '', 
                    model = '', 
                    parameters = { }, 
                    prompt = '', ),
                is_ai_generated = True,
                logo_img_url = '',
                org_guid = 'org_123',
                primary_color = '',
                secondary_color = '',
                spacing = neurograph.v1.models.organizations/spacing_config.organizations.SpacingConfig(
                    base_unit = 56, 
                    scale = '', ),
                tertiary_color = '',
                typography = neurograph.v1.models.organizations/typography_config.organizations.TypographyConfig(
                    body_size = '', 
                    font_family = '', 
                    heading_scale = 1.337, ),
                version = 56
            )
        else:
            return OrganizationsBrandDetailResponse(
        )
        """

    def testOrganizationsBrandDetailResponse(self):
        """Test OrganizationsBrandDetailResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
