# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.organizations_test_accessibility_response import OrganizationsTestAccessibilityResponse

class TestOrganizationsTestAccessibilityResponse(unittest.TestCase):
    """OrganizationsTestAccessibilityResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> OrganizationsTestAccessibilityResponse:
        """Test OrganizationsTestAccessibilityResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `OrganizationsTestAccessibilityResponse`
        """
        model = OrganizationsTestAccessibilityResponse()
        if include_optional:
            return OrganizationsTestAccessibilityResponse(
                color_pair_results = [
                    neurograph.v1.models.utils/color_pair_result.utils.ColorPairResult(
                        background_color = '', 
                        contrast_ratio = 1.337, 
                        foreground_color = '', 
                        passes_large_aa = True, 
                        passes_large_aaa = True, 
                        passes_normal_aa = True, 
                        passes_normal_aaa = True, 
                        passes_ui_aa = True, 
                        recommendation = '', )
                    ],
                error = '',
                issues = [
                    ''
                    ],
                level = '',
                passes_aa = True,
                passes_aaa = True,
                recommendations = [
                    ''
                    ],
                score = 56
            )
        else:
            return OrganizationsTestAccessibilityResponse(
        )
        """

    def testOrganizationsTestAccessibilityResponse(self):
        """Test OrganizationsTestAccessibilityResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
