# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.reporting_category_spend_data import ReportingCategorySpendData

class TestReportingCategorySpendData(unittest.TestCase):
    """ReportingCategorySpendData unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ReportingCategorySpendData:
        """Test ReportingCategorySpendData
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ReportingCategorySpendData`
        """
        model = ReportingCategorySpendData()
        if include_optional:
            return ReportingCategorySpendData(
                categories = [
                    ''
                    ],
                data = [
                    neurograph.v1.models.reporting/category_spend_week.reporting.CategorySpendWeek(
                        spend = {
                            'key' : 1.337
                            }, 
                        week = '', )
                    ],
                period_comparison = neurograph.v1.models.reporting/period_comparison.reporting.PeriodComparison(
                    change_percentage = 1.337, 
                    current_period_spend = 1.337, 
                    previous_period_spend = 1.337, 
                    trend = '', ),
                total_spend = 1.337,
                weeks = [
                    ''
                    ]
            )
        else:
            return ReportingCategorySpendData(
        )
        """

    def testReportingCategorySpendData(self):
        """Test ReportingCategorySpendData"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
