# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.reports_recommendation import ReportsRecommendation

class TestReportsRecommendation(unittest.TestCase):
    """ReportsRecommendation unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ReportsRecommendation:
        """Test ReportsRecommendation
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ReportsRecommendation`
        """
        model = ReportsRecommendation()
        if include_optional:
            return ReportsRecommendation(
                action_url = '/campaigns/create?segment=a',
                category = 'engagement',
                id = '',
                priority = 'high',
                title = 'Increase email frequency for Segment A'
            )
        else:
            return ReportsRecommendation(
        )
        """

    def testReportsRecommendation(self):
        """Test ReportsRecommendation"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
