# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.organizations_brand_generation_response import OrganizationsBrandGenerationResponse

class TestOrganizationsBrandGenerationResponse(unittest.TestCase):
    """OrganizationsBrandGenerationResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> OrganizationsBrandGenerationResponse:
        """Test OrganizationsBrandGenerationResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `OrganizationsBrandGenerationResponse`
        """
        model = OrganizationsBrandGenerationResponse()
        if include_optional:
            return OrganizationsBrandGenerationResponse(
                brand = neurograph.v1.models.openai/generated_brand.openai.GeneratedBrand(
                    accessibility = neurograph.v1.models.openai/accessibility_info.openai.AccessibilityInfo(
                        contrast_ratios = {
                            'key' : 1.337
                            }, 
                        notes = '', 
                        passes = '', ), 
                    analysis = neurograph.v1.models.openai/brand_analysis.openai.BrandAnalysis(
                        design_style = '', 
                        industry_fit = '', 
                        personality = [
                            ''
                            ], ), 
                    colors = neurograph.v1.models.openai/brand_colors.openai.BrandColors(
                        color1 = '', 
                        color2 = '', 
                        color3 = '', 
                        color4 = '', 
                        color5 = '', 
                        primary_color = '', 
                        secondary_color = '', 
                        tertiary_color = '', ), 
                    reasoning = '', ),
                error = '',
                success = True
            )
        else:
            return OrganizationsBrandGenerationResponse(
        )
        """

    def testOrganizationsBrandGenerationResponse(self):
        """Test OrganizationsBrandGenerationResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
