# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.knowledge_customer_response import KnowledgeCustomerResponse

class TestKnowledgeCustomerResponse(unittest.TestCase):
    """KnowledgeCustomerResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> KnowledgeCustomerResponse:
        """Test KnowledgeCustomerResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `KnowledgeCustomerResponse`
        """
        model = KnowledgeCustomerResponse()
        if include_optional:
            return KnowledgeCustomerResponse(
                data = [
                    neurograph.v1.models.db/knowledge_customer.db.KnowledgeCustomer(
                        client_id = '', 
                        email = '', 
                        entity_id = '', 
                        first_name = '', 
                        last_name = '', 
                        phone = '', )
                    ],
                error = '',
                query = neurograph.v1.models.knowledge/customer_query.knowledge.CustomerQuery(
                    client_id = '', 
                    email = '', 
                    first_name = '', 
                    last_name = '', 
                    limit = 56, 
                    offset = 56, 
                    phone = '', )
            )
        else:
            return KnowledgeCustomerResponse(
        )
        """

    def testKnowledgeCustomerResponse(self):
        """Test KnowledgeCustomerResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
